Learn R Programming

UPG (version 0.3.0)

UPG.Diag: MCMC Diagnostics for UPG.Probit, UPG.Logit, UPG.MNL and UPG.Binomial objects using coda

Description

UPG.Diag computes a number of MCMC diagnostics based on the Markov chains that are contained in the model output returned by UPG.

Usage

UPG.Diag(object = NULL)

Arguments

object

an object of class UPG.Probit, UPG.Logit, UPG.MNL or UPG.Binomial.

Value

Returns a list containing effective sample size, effective sampling rate and inefficiency factors for each coefficient. In addition, maximum, minimum and median of these measures are returned.

Examples

Run this code
# NOT RUN {
# estimate a probit model using example data
library(UPG)
data(lfp)
y = lfp[,1]
X = lfp[,-1]
results.probit = UPG(y = y, X = X, model = "probit")

# compute MCMC diagnostics
UPG.Diag(results.probit)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab