UPG.Binomial objectsUPG.Diag.Binomial computes inefficiency factors, effective sample size and effective sampling rate based on the posterior distributions in an UPG.Binomial object.
UPG.Diag.Binomial(object = NULL)an object of class UPG.Binomial.
Returns a list containing effective sample size, effective sampling rate and inefficiency factors for each coefficient.