UPG.Diag.Logit: MCMC Diagnostics for UPG.Logit objects
Description
UPG.Diag.Logit computes inefficiency factors, effective sample size and effective sampling rate based on the posterior distributions in a UPG.Logit object.
Usage
UPG.Diag.Logit(object = NULL)
Value
Returns a list containing effective sample size, effective sampling rate and inefficiency factors for each coefficient.
Arguments
- object
an object of class UPG.Logit.