UPG.Diag.MNL: MCMC Diagnostics for UPG.MNL objects
Description
UPG.Diag.MNL computes inefficiency factors, effective sample size and effective sampling rate based on the posterior distributions in an UPG.MNL object.
Usage
UPG.Diag.MNL(object = NULL)
Arguments
object
an object of class UPG.MNL.
Value
Returns a list containing effective sample size, effective sampling rate and inefficiency factors for each coefficient.