UPG.Diag.Probit: MCMC Diagnostics for UPG.Probit objects
Description
UPG.Diag.Probit computes inefficiency factors, effective sample size and effective sampling rate based on the posterior distributions in an UPG.Probit object.
Usage
UPG.Diag.Probit(object = NULL)
Arguments
object
an object of class UPG.Probit.
Value
Returns a list containing effective sample size, effective sampling rate and inefficiency factors for each coefficient.